@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for openSUSE 11.4's 2.6.37 kernel.
+# This is a kernel build script for openSUSE 11.1's 2.6.27 kernel.
 #
 
 die () {
@@ -51,8 +51,8 @@ then
  case "$1" in
  kernel-module-*)    ;; # Fedora kernel module package names start with
  		       # kernel-module.
-+ccs-kernel-*)      kernel_flavor=${1#ccs-kernel-} ;;
- kernel*)	    kernel_flavor=${1#kernel-} ;;
++ccs-kernel-*)      is_kernel_package=1 ;;
+ kernel*)	    is_kernel_package=1 ;;
  esac
  
 EOF
@@ -60,56 +60,65 @@ fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-source-2.6.37.6-0.5.1.src.rpm ]
+if [ ! -r kernel-source-2.6.27.56-0.1.1.src.rpm ]
 then
-    wget http://download.opensuse.org/update/11.4/rpm/src/kernel-source-2.6.37.6-0.5.1.src.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/11.1/rpm/src/kernel-source-2.6.27.56-0.1.1.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-source-2.6.37.6-0.5.1.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-source-2.6.37.6-0.5.1.src.rpm || die "Can't install source package."
-
-if [ ! -r kernel-default-2.6.37.6-0.5.1.nosrc.rpm ]
-then
-    wget http://download.opensuse.org/update/11.4/rpm/src/kernel-default-2.6.37.6-0.5.1.nosrc.rpm || die "Can't download source package."
-fi
-rpm --checksig kernel-default-2.6.37.6-0.5.1.nosrc.rpm || die "Can't verify signature."
-rpm -ivh kernel-default-2.6.37.6-0.5.1.nosrc.rpm || die "Can't install source package."
+rpm --checksig kernel-source-2.6.27.56-0.1.1.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-source-2.6.27.56-0.1.1.src.rpm || die "Can't install source package."
 
 cd /usr/src/packages/SOURCES/ || die "Can't chdir to /usr/src/packages/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.1-20110511.tar.gz ]
+if [ ! -r ccs-patch-1.8.2-20110620.tar.gz ]
 then
-    wget -O ccs-patch-1.8.1-20110511.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.1-20110511.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.2-20110620.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.2-20110620.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
-cp -p /usr/src/packages/SPECS/kernel-default.spec . || die "Can't copy spec file."
+cp -p /usr/src/packages/SOURCES/kernel-default.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
 --- kernel-default.spec
 +++ kernel-default.spec
-@@ -53,10 +53,10 @@
- %define install_vdso 0
+@@ -63,13 +63,13 @@
+ %if %build_vanilla || %build_kdump || %CONFIG_MODULES != "y"
+ %define split_packages 0
+ %else
+-%define split_packages 1
++%define split_packages 0
  %endif
  
 -Name:           kernel-default
 +Name:           ccs-kernel-default
  Summary:        The Standard Kernel
- Version:        2.6.37.6
--Release:        0.5.1
-+Release:        0.5.1_tomoyo_1.8.1p3
- %if %using_buildservice
- %else
- %endif
-@@ -303,6 +303,11 @@
- %endif
- 	%_sourcedir/series.conf .. $SYMBOLS
+ Version:        2.6.27.56
+-Release:        0.1.1
++Release:        0.1.1_tomoyo_1.8.2
+ License:        GPL v2 only
+ Group:          System/Kernel
+ Url:            http://www.kernel.org/
+@@ -342,6 +342,10 @@
+ source .rpm-defs
  
+ cd linux-2.6.27
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.1-20110511.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.37-suse-11.4.diff
-+cat config.ccs >> ../config/%cpu_arch_flavor
-+
- cd %kernel_build_dir
++tar -zxf %_sourcedir/ccs-patch-1.8.2-20110620.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.27-suse-11.1.diff
++cat config.ccs >> .config
+ cp .config .config.orig
+ %if %{tolerate_unknown_new_config_options}
+ MAKE_ARGS="$MAKE_ARGS -k"
+EOF
+patch << "EOF" || die "Can't patch spec file."
+--- kernel-default.spec
++++ kernel-default.spec
+@@ -97,7 +97,7 @@
+ #!BuildIgnore:  perl-Bootloader mkinitrd
  
- if [ -f %_sourcedir/localversion ] ; then
+ %if ! 0%{?opensuse_bs}
+-BuildRequires:  kernel-dummy
++#BuildRequires:  kernel-dummy
+ %endif
+ %ifarch ia64
+ # arch/ia64/scripts/unwcheck.py
 EOF
 sed -e 's:^Provides:#Provides:' -e 's:^Obsoletes:#Obsoletes:' -e 's:-n kernel:-n ccs-kernel:' kernel-default.spec > ccs-kernel.spec || die "Can't edit spec file."
 echo ""
