@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.8.1+   2011/04/11
+ * Version: 1.8.2   2011/06/20
  */
 
 #include "internal.h"
@@ -79,16 +79,12 @@ const u8 ccs_pn2mac[CCS_MAX_PATH_NUMBER_OPERATION] = {
  */
 void ccs_put_name_union(struct ccs_name_union *ptr)
 {
-	if (!ptr)
-		return;
-	if (ptr->is_group)
-		ccs_put_group(ptr->group);
-	else
-		ccs_put_name(ptr->filename);
+	ccs_put_group(ptr->group);
+	ccs_put_name(ptr->filename);
 }
 
 /**
- * ccs_put_name_union - Drop reference on "struct ccs_number_union".
+ * ccs_put_number_union - Drop reference on "struct ccs_number_union".
  *
  * @ptr: Pointer to "struct ccs_number_union".
  *
@@ -96,8 +92,7 @@ void ccs_put_name_union(struct ccs_name_union *ptr)
  */
 void ccs_put_number_union(struct ccs_number_union *ptr)
 {
-	if (ptr && ptr->is_group)
-		ccs_put_group(ptr->group);
+	ccs_put_group(ptr->group);
 }
 
 /**
@@ -111,7 +106,7 @@ void ccs_put_number_union(struct ccs_number_union *ptr)
 bool ccs_compare_number_union(const unsigned long value,
 			      const struct ccs_number_union *ptr)
 {
-	if (ptr->is_group)
+	if (ptr->group)
 		return ccs_number_matches_group(value, value, ptr->group);
 	return value >= ptr->values[0] && value <= ptr->values[1];
 }
@@ -127,7 +122,7 @@ bool ccs_compare_number_union(const unsigned long value,
 const struct ccs_path_info *ccs_compare_name_union
 (const struct ccs_path_info *name, const struct ccs_name_union *ptr)
 {
-	if (ptr->is_group)
+	if (ptr->group)
 		return ccs_path_matches_group(name, ptr->group);
 	if (ccs_path_matches_pattern(name, ptr->filename))
 		return ptr->filename;
@@ -318,7 +313,7 @@ static bool ccs_check_path2_acl(struct ccs_request_info *r,
 }
 
 /**
- * ccs_check_cmkdev_acl - Check permission for path number number number operation.
+ * ccs_check_mkdev_acl - Check permission for path number number number operation.
  *
  * @r:   Pointer to "struct ccs_request_info".
  * @ptr: Pointer to "struct ccs_acl_info".
@@ -393,7 +388,7 @@ static int ccs_update_path_acl(const u16 perm, struct ccs_acl_param *param)
 		.perm = perm
 	};
 	int error;
-	if (!ccs_parse_name_union(ccs_read_token(param), &e.name))
+	if (!ccs_parse_name_union(param, &e.name))
 		error = -EINVAL;
 	else
 		error = ccs_update_domain(&e.head, sizeof(e), param,
@@ -462,10 +457,10 @@ static int ccs_update_mkdev_acl(const u8 perm, struct ccs_acl_param *param)
 		.perm = perm
 	};
 	int error;
-	if (!ccs_parse_name_union(ccs_read_token(param), &e.name) ||
-	    !ccs_parse_number_union(ccs_read_token(param), &e.mode) ||
-	    !ccs_parse_number_union(ccs_read_token(param), &e.major) ||
-	    !ccs_parse_number_union(ccs_read_token(param), &e.minor))
+	if (!ccs_parse_name_union(param, &e.name) ||
+	    !ccs_parse_number_union(param, &e.mode) ||
+	    !ccs_parse_number_union(param, &e.major) ||
+	    !ccs_parse_number_union(param, &e.minor))
 		error = -EINVAL;
 	else
 		error = ccs_update_domain(&e.head, sizeof(e), param,
@@ -535,8 +530,8 @@ static int ccs_update_path2_acl(const u8 perm, struct ccs_acl_param *param)
 		.perm = perm
 	};
 	int error;
-	if (!ccs_parse_name_union(ccs_read_token(param), &e.name1) ||
-	    !ccs_parse_name_union(ccs_read_token(param), &e.name2))
+	if (!ccs_parse_name_union(param, &e.name1) ||
+	    !ccs_parse_name_union(param, &e.name2))
 		error = -EINVAL;
 	else
 		error = ccs_update_domain(&e.head, sizeof(e), param,
@@ -553,7 +548,7 @@ static int ccs_update_path2_acl(const u8 perm, struct ccs_acl_param *param)
  * @a: Pointer to "struct ccs_acl_info".
  * @b: Pointer to "struct ccs_acl_info".
  *
- * Returns true if @a == @b except permission bits, false otherwise.
+ * Returns true if @a == @b, false otherwise.
  */
 static bool ccs_same_mount_acl(const struct ccs_acl_info *a,
 			       const struct ccs_acl_info *b)
@@ -579,10 +574,10 @@ static int ccs_update_mount_acl(struct ccs_acl_param *param)
 {
 	struct ccs_mount_acl e = { .head.type = CCS_TYPE_MOUNT_ACL };
 	int error;
-	if (!ccs_parse_name_union(ccs_read_token(param), &e.dev_name) ||
-	    !ccs_parse_name_union(ccs_read_token(param), &e.dir_name) ||
-	    !ccs_parse_name_union(ccs_read_token(param), &e.fs_type) ||
-	    !ccs_parse_number_union(ccs_read_token(param), &e.flags))
+	if (!ccs_parse_name_union(param, &e.dev_name) ||
+	    !ccs_parse_name_union(param, &e.dir_name) ||
+	    !ccs_parse_name_union(param, &e.fs_type) ||
+	    !ccs_parse_number_union(param, &e.flags))
 		error = -EINVAL;
 	else
 		error = ccs_update_domain(&e.head, sizeof(e), param,
@@ -758,7 +753,7 @@ static int ccs_new_open_permission(struct file *filp)
 #endif
 
 /**
- * ccs_path_perm - Check permission for "unlink", "rmdir", "truncate", "symlink", "getattr", "chroot" and "unmount".
+ * ccs_path_perm - Check permission for "unlink", "rmdir", "truncate", "symlink", "append", "getattr", "chroot" and "unmount".
  *
  * @operation: Type of operation.
  * @dentry:    Pointer to "struct dentry".
@@ -1001,8 +996,8 @@ static int ccs_update_path_number_acl(const u8 perm,
 		.perm = perm
 	};
 	int error;
-	if (!ccs_parse_name_union(ccs_read_token(param), &e.name) ||
-	    !ccs_parse_number_union(ccs_read_token(param), &e.number))
+	if (!ccs_parse_name_union(param, &e.name) ||
+	    !ccs_parse_number_union(param, &e.number))
 		error = -EINVAL;
 	else
 		error = ccs_update_domain(&e.head, sizeof(e), param,
